betty.test_utils.config package - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.test_utils.config package

## Subpackages

- betty.test_utils.config.collections package
  - Submodules
    - betty.test_utils.config.collections.mapping module
      - `ConfigurationMappingTestBase`
      - `OrderedConfigurationMappingTestBase`
    - betty.test_utils.config.collections.sequence module
      - `ConfigurationSequenceTestBase`
        - `ConfigurationSequenceTestBase.get_configuration_keys()`
        - `ConfigurationSequenceTestBase.test___contains__()`
        - `ConfigurationSequenceTestBase.test___iter__()`
  - Module contents
    - `ConfigurationCollectionTestBase`
      - `ConfigurationCollectionTestBase.get_configuration_keys()`
      - `ConfigurationCollectionTestBase.get_configurations()`
      - `ConfigurationCollectionTestBase.get_sut()`
      - `ConfigurationCollectionTestBase.test___delitem__()`
      - `ConfigurationCollectionTestBase.test___getitem__()`
      - `ConfigurationCollectionTestBase.test___iter__()`
      - `ConfigurationCollectionTestBase.test___len__()`
      - `ConfigurationCollectionTestBase.test_append()`
      - `ConfigurationCollectionTestBase.test_insert()`
      - `ConfigurationCollectionTestBase.test_keys()`
      - `ConfigurationCollectionTestBase.test_prepend()`
      - `ConfigurationCollectionTestBase.test_replace_with_items()`
      - `ConfigurationCollectionTestBase.test_replace_without_items()`
      - `ConfigurationCollectionTestBase.test_values()`

## Module contents

Test utilities for `betty.config`.

class betty.test_utils.config.DummyConfiguration

  Bases: `Configuration`

  A dummy `betty.config.Configuration` implementation.

  __init__(value: str | None = None)
  dump() → bool | int | float | str | None | MutableSequence[bool | int | float | str | None | MutableSequence[Dump] | MutableMapping[str, Dump]] | MutableMapping[str, bool | int | float | str | None | MutableSequence[Dump] | MutableMapping[str, Dump]]

    Produce a serialized data dump of `self`.

  load(dump: bool | int | float | str | None | MutableSequence[bool | int | float | str | None | MutableSequence[Dump] | MutableMapping[str, Dump]] | MutableMapping[str, bool | int | float | str | None | MutableSequence[Dump] | MutableMapping[str, Dump]]) → None

    Load a serialized data dump into `self`.

    Raises:

      betty.assertion.error.AssertionFailed – Raised if the dump is invalid.